@@ -17,22 +17,26 @@ class Trick(object):
         if not cards:
             cards = []
         # self.index = index
-        self.cards = cards
-        self.start_suit = None
+        self.cards = cards  # a list of Card instances
+        self._start_suit = None
         self._leader = None
         self.winner = None
         self.note_keys = ['' for _ in range(4)]
 
     def __repr__(self):
         """ A repr string for the object."""
-        cards = ', '.join([card.name for card in self._cards])
-        return f'Trick({cards})'
+        # cards = ', '.join([card.name for card in self._cards])
+        # return f'Trick({cards})'
+        cards = ', '.join([f'"{card.name}"' for card in self._cards])
+        # text = (f'Trick: Leader: {self._leader}, winner: {self.winner}, '
+        #         f'cards: {cards}')
+        return f'Trick(cards={cards})'
 
     def __str__(self):
         """ A str string for the object."""
         cards = ', '.join([card.name for card in self._cards])
         text = (f'Trick: Leader: {self._leader}, winner: {self.winner}, '
-                f'start suit: {self.start_suit}, cards: {cards}')
+                f', cards: {cards}')
         return text
 
     def complete(self, trump_suit=None):
@@ -69,13 +73,15 @@ class Trick(object):
         if not isinstance(value, list):
             raise TypeError('Cards not a list.')
         card_list = []
-        for card in value:
+        for index, card in enumerate(value):
             if isinstance(card, str):
                 if card not in CARD_NAMES:
                     raise ValueError('Invalid card name')
                 card = Card(card)
             elif not isinstance(card, Card):
                 raise TypeError('Item is not a card')
+            if index == 0:
+                self._start_suit = card.suit
             card_list.append(card)
         self._cards = card_list
         
@@ -87,8 +93,14 @@ class Trick(object):
     @leader.setter
     def leader(self, value):
         """Set the value of the leader as a string."""
-        if not isinstance(value, str):
-            raise TypeError('Leader must be a string')
-        if value not in SEATS:
-            raise ValueError('Invalid seat')
-        self._leader = value
+        if value:
+            if not isinstance(value, str):
+                raise TypeError('Leader must be a string')
+            if value not in SEATS:
+                raise ValueError('Invalid seat')
+            self._leader = value
+
+    @property
+    def start_suit(self):
+        """Return the Suit of the lead card in the trick."""
+        return self._start_suit
