@@ -430,8 +430,8 @@ def test_board_given_three_hands():
     assert len(board.hands_by_seat) == 4
     missing_hand = board.hands[3]
     # missing_hand [KS, 9S, KH, 9H, 4H, AD, TD, 7D, 5D, 4D, 3D, 2D, 9C]
-    assert missing_hand[1].name == '9S'
-    assert missing_hand[-1].name == '9C'
+    assert Card('9S') in missing_hand.cards
+    assert Card('9C') in missing_hand.cards
 
 
 def test_board_hands_by_index_init():
